@@ -377,7 +377,7 @@ classdef string
 ##                             Available Methods                              ##
 ##                                                                            ##
 ## 'size'             'ndims'            'numel'            'strlength'       ##
-## 'count'                                                                    ##
+## 'length'           'keyHash'                                               ##
 ##                                                                            ##
 ################################################################################
 
@@ -460,6 +460,64 @@ classdef string
       out(TF) = cell2mat (cellfun (fcn, this.strs(TF), "UniformOutput", false));
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn {string} {@var{N} =} length (@var{str})
+    ##
+    ## Length of a string vector.
+    ##
+    ## @code{@var{N} = length (@var{str})} returns the size of the longest
+    ## dimension of the string array @var{str}, unless any of its dimensions
+    ## has zero length, in which case @code{length (@var{D})} returns 0.
+    ##
+    ## @end deftypefn
+    function N = length (this)
+      if (isempty (this.strs))
+        N = 0;
+      else
+        N = max (size (this.strs));
+      endif
+    endfunction
+
+    ## -*- texinfo -*-
+    ## @deftypefn {string} {@var{hey} =} keyHash (@var{str})
+    ##
+    ## Generate a hash code for string array.
+    ##
+    ## @code{@var{h} = keyHash (@var{str})} generates a @qcode{uint64} scalar
+    ## that represents the input array @var{str}.  @code{keyHash} utilizes the
+    ## 64-bit FMV-1a variant of the Fowler-Noll-Vo non-cryptographic hash
+    ## function.
+    ##
+    ## @code{@var{h} = keyHash (@var{str}), @var{base}} also generates a 64-bit
+    ## hash code using @var{base} as the offset basis for the FNV-1a hash
+    ## algorithm.  @var{base} must be a @qcode{uint64} integer type scalar.  Use
+    ## this syntax to cascade @code{keyHash} on multiple objects for which a
+    ## single hash code is required.
+    ##
+    ## Note that unlike MATLAB, this implementation does no use any random seed.
+    ## As a result, @code{keyHash} will always generate the exact same hash key
+    ## for any particular input across different workers and Octave sessions.
+    ##
+    ## @end deftypefn
+    function key = keyHash (this, base = [])
+      ## Initialize string with size and class name
+      size_str = sprintf ('%dx', size (this.strs))(1:end-1);
+      init_str = [size_str 'string'];
+      if (base)
+        if (! (isscalar (base) && isa (base, 'uint64')))
+          error ("string.keyHash: BASE must be a UINT64 scalar.");
+        endif
+        key = __ckeyHash__(init_str, base);
+      else
+        key = __ckeyHash__(init_str);
+      endif
+      if (! isempty (this.strs))
+        strs = [this.strs{:}];
+        key = __ckeyHash__(strs, key);
+        key = __nkeyHash__(this.isMissing(:), key);
+      endif
+    endfunction
+
   endmethods
 
 ################################################################################
@@ -943,32 +1001,12 @@ classdef string
 ##                                                                            ##
 ################################################################################
 
-  methods (Access = public)
-
-    function out = append (this, varargin)
-      error ("string.append: not implemented yet.");
-    endfunction
+  methods (Hidden)
 
     function out = compose (this, varargin)
       error ("string.compose: not implemented yet.");
     endfunction
 
-    ## -*- texinfo -*-
-    ## @deftypefn {string} {@var{newstr} =} erase (@var{str}, @var{pat})
-    ##
-    ## Remove content from string array.
-    ##
-    ## @code{@var{newstr} = erase (@var{str}, @var{pat})} removes the
-    ## occurences of @var{pat} from each element of the string array @var{str}.
-    ## @var{newstr} is a string array of the same size as @var{str}.
-    ##
-    ## @end deftypefn
-    function out = erase (this, pat)
-      pat = char (pat);
-      out = this;
-      out.strs = strrep (this.strs, pat, '');
-    endfunction
-
     function out = eraseBetween (this, start, stop)
       error ("string.eraseBetween: not implemented yet.");
     endfunction
@@ -1005,6 +1043,99 @@ classdef string
       error ("string.replaceBetween: not implemented yet.");
     endfunction
 
+    function out = sort (this, varargin)
+      error ("string.sort: not implemented yet.");
+    endfunction
+
+    function out = split (this, varargin)
+      error ("string.split: not implemented yet.");
+    endfunction
+
+    function out = strip (this, varargin)
+      error ("string.strip: not implemented yet.");
+    endfunction
+
+    function out = pad (this, varargin)
+      error ("string.pad: not implemented yet.");
+    endfunction
+
+    function out = join (this, varargin)
+      error ("string.join: not implemented yet.");
+    endfunction
+
+  endmethods
+
+  methods (Access = public)
+
+    ## -*- texinfo -*-
+    ## @deftypefn {string} {@var{newstr} =} append (@var{str1}, @dots{}, @var{strN})
+    ##
+    ## Remove content from string array.
+    ##
+    ## @code{@var{newstr} = append (@var{str1}, @dots{}, @var{strN})} combines
+    ## the text from each input argument, @var{str1}, @dots{}, @var{strN}),
+    ## which must be either string arrays, cell arrays of character vectors, or
+    ## character vectors or matrices.  All input arguments must be of compatible
+    ## sizes.  Character vectors are treated as a single text element and
+    ## character matrices are treated as a column of elements.  @code{apped}
+    ## preserves any trailing white spaces, unlike the @code{strcat} function.
+    ##
+    ## @end deftypefn
+    function out = append (varargin)
+      ## Check input for valid types
+      fcn = @(x) iscellstr (x) || ischar (x) || isa (x, 'string');
+      dtypes = cellfun (fcn, varargin);
+      if (! all (dtypes))
+        error (strcat ("string.append: input arguments must be strindg", ...
+                       " arrays, cell arrays of character vectors, or", ...
+                       " character matrices."));
+      endif
+      ## Convert all inputs to string arrays
+      ctypes = cellfun (@(x) ! isa (x, 'string'), varargin);
+      if (any (ctypes))
+        varargin(ctypes) = cellfun (@(x) string (char (x)), ...
+                                    varargin(ctypes), "UniformOutput", false);
+      endif
+      ## Handle compatible dimensions
+      out = varargin{1};
+      in_sz = cellfun (@size, varargin, "UniformOutput", false);
+      strArgs = cellfun (@(x) x.strs, varargin, 'UniformOutput', false);
+      ismArgs = cellfun (@(x) x.isMissing, varargin, 'UniformOutput', false);
+      if (isequal (in_sz{:}))
+        out.strs = strcat (strArgs{:});
+        out.isMissing = and (ismArgs{:});
+      else
+        try
+          out.isMissing = and (ismArgs{:});
+          szo = size (out.isMissing);
+        catch
+          error ("string.append: inputs have incompatible sizes.");
+        end_try_catch
+        for n = 1:numel (strArgs)
+          strArg = strArgs{n};
+          newsz = szo ./ size (strArg);
+          strArgs{n} = repmat (strArg, newsz);
+        endfor
+        out.strs = strcat (strArgs{:});
+      endif
+    endfunction
+
+    ## -*- texinfo -*-
+    ## @deftypefn {string} {@var{newstr} =} erase (@var{str}, @var{pat})
+    ##
+    ## Remove content from string array.
+    ##
+    ## @code{@var{newstr} = erase (@var{str}, @var{pat})} removes the
+    ## occurences of @var{pat} from each element of the string array @var{str}.
+    ## @var{newstr} is a string array of the same size as @var{str}.
+    ##
+    ## @end deftypefn
+    function out = erase (this, pat)
+      pat = char (pat);
+      out = this;
+      out.strs = strrep (this.strs, pat, '');
+    endfunction
+
     ## -*- texinfo -*-
     ## @deftypefn {string} {@var{newstr} =} reverse (@var{str})
     ##
@@ -1027,14 +1158,6 @@ classdef string
       out.isMissing = this.isMissing;
     endfunction
 
-    function out = sort (this, varargin)
-      error ("string.sort: not implemented yet.");
-    endfunction
-
-    function out = split (this, varargin)
-      error ("string.split: not implemented yet.");
-    endfunction
-
     ## -*- texinfo -*-
     ## @deftypefn {string} {@var{newstr} =} strcat (@var{str1}, @var{str2}, @dots{})
     ##
@@ -1064,20 +1187,23 @@ classdef string
       out = string (strcat (args{:}));
     endfunction
 
-    function out = strip (this, varargin)
-      error ("string.strip: not implemented yet.");
-    endfunction
-
-    function out = pad (this, varargin)
-      error ("string.pad: not implemented yet.");
-    endfunction
-
-    function out = join (this, varargin)
-      error ("string.join: not implemented yet.");
-    endfunction
-
+    ## -*- texinfo -*-
+    ## @deftypefn {string} {@var{newstr} =} plys (@var{str1}, @var{str2})
+    ##
+    ## Append strings.
+    ##
+    ## @code{@var{newstr} = lower (@var{str})} is the equivalent of the syntax
+    ## @code{@var{newstr} = @var{str1} + @var{str2}} and appends @var{str2} to
+    ## @var{str1}.  Both input arguments must be string arrays of compatible
+    ## size.
+    ##
+    ## @end deftypefn
     function out = plus (str1, str2)
-      error ("string.plus: not implemented yet.");
+      if (isa (str1, 'string') && isa (str2, 'string'))
+        out = append (str1, str2);
+      else
+        error ("string.plus: both STR1 and STR2 must be string arrays.");
+      endif
     endfunction
 
     ## -*- texinfo -*-
@@ -1110,6 +1236,44 @@ classdef string
       out.strs = upper (this.strs);
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn  {string} {@var{B} =} unique (@var{A})
+    ## @deftypefnx {string} {@var{B} =} unique (@var{A}, @qcode{'rows'})
+    ## @deftypefnx {string} {[@var{B}, @var{ixA}, @var{ixB}] =} unique (@dots{})
+    ## @deftypefnx {string} {@dots{} =} unique (@dots{}, @var{order})
+    ## @deftypefnx {string} {@dots{} =} unique (@dots{}, @var{occurence})
+    ##
+    ## Unique values in a string array.
+    ##
+    ## @code{@var{B} = unique (@var{A})} returns the unique values of the string
+    ## array @var{A} in the string vector @var{B} sorted lexicographically.  If
+    ## If @var{A} is a column vector, then @var{B} is also a column vector,
+    ## otherwise @code{unique} returns a row vector.
+    ##
+    ## @code{@var{B} = unique (@var{A}, @qcode{'rows'})} returns the unique rows
+    ## of the string matrix @var{A} in the string matrix @var{B} sorted in
+    ## lexicographical order.
+    ##
+    ## @code{[@var{B}, @var{ixA}, @var{ixB}] = unique (@dots{})} also returns
+    ## index vectors @var{ixA} and @var{ixB} such that
+    ## @code{@var{B} = @var{A}(@var{ixA})} and
+    ## @code{@var{A} = @var{B}(@var{ixB})}, unless the @qcode{'rows'} optional
+    ## argument is given, in which case @code{@var{B} = @var{A}(@var{ixA},:)}
+    ## and @code{@var{A} = @var{B}(@var{ixB},:)}.
+    ##
+    ## @code{@dots{} = unique (@dots{}, @var{order})} also specifies the order
+    ## of the returned unique values.  @var{order} may be either
+    ## @qcode{'sorted'}, which is the default behavior, or @qcode{'stable'}, in
+    ## which case the unique values are returned in order of appearance.
+    ##
+    ## @code{@dots{} = unique (@dots{}, @var{occurence})} also specifies the
+    ## which index is returned in @var{ixA}, where there are repeated values or
+    ## rows (if opted) in the input categorical array.  @var{occurence} may be
+    ## either @qcode{'first'}, which is the default and returns the index of the
+    ## first occurence of each unique value, or @qcode{'last'}, in which case
+    ## the last occurence of each unique value is returned.
+    ##
+    ## @end deftypefn
     function [B, ixA, ixB] = unique (A, varargin)
       ## Handle 'rows' option
       do_rows = false;
@@ -1169,44 +1333,67 @@ classdef string
 ##                             Available Methods                              ##
 ##                                                                            ##
 ## 'cat'              'horzcat'          'vertcat'          'repmat'          ##
-## 'reshape'          'circshift'        'permute'          'ipermute'        ##
-## 'transpose'        'ctranspose'                                            ##
+## 'repelem'          'repelems'         'reshape'          'circshift'       ##
+## 'permute'          'ipermute'         'transpose'        'ctranspose'      ##
 ##                                                                            ##
 ################################################################################
 
-  methods (Hidden)
+  methods (Access = public)
 
+    ## -*- texinfo -*-
+    ## @deftypefn {string} {@var{C} =} cat (@var{dim}, @var{A}, @var{B}, @dots{})
+    ##
+    ## Concatenate string arrays.
+    ##
+    ## @code{@var{C} = cat (@var{dim}, @var{A}, @var{B}, @dots{})} concatenates
+    ## string arrays @var{A}, @var{B}, @dots{} along dimension @var{dim}.  All
+    ## input arrays must have the same size except along the operating dimension
+    ## @var{dim}.  Any of the input arrays may also be character matrixes, cell
+    ## arrays of character vectors, numeric arrays, or logical arrays of
+    ## compatible size.
+    ##
+    ## @end deftypefn
     function out = cat (dim, varargin)
       args = varargin;
+      ## For categorical, datetime, and duration arrays being present in the
+      ## input arguments, call their constructor and forward all input to their
+      ## respective concatenation method.
       for i = 1:numel (args)
         if (iscategorical (args{i}))
           try
             cat_array = cellfun (@categorical, varargin, 'UniformOutput', false);
             out = [cat_array{:}];
             return;
-          catch (me)
-            error (me);
+          catch (err)
+            error (err.message);
           end_try_catch
         elseif (isdatetime (args{i}))
           try
             dat_array = cellfun (@datetime, varargin, 'UniformOutput', false);
             out = [dat_array{:}];
             return;
-          catch (me)
-            error (me);
+          catch (err)
+            error (err.message);
           end_try_catch
         elseif (isduration (args{i}))
           try
             dur_array = cellfun (@duration, varargin, 'UniformOutput', false);
             out = [dur_array{:}];
             return;
-          catch (me)
-            error (me);
+          catch (err)
+            error (err.message);
+          end_try_catch
+        ## Grab everything else and try converting it a to string array
+        elseif (! isa (args{i}, 'string'))
+          try
+            args(i) = string (args{i});
+          catch
+            error ("string.cat: cannot concatenate string arrays with 's'.", ...
+                   class (args{i}));
           end_try_catch
-        else
-          args{i} = string (args{i});
         endif
       endfor
+      ## Concatenate strings
       out = args{1};
       tmp = cellfun (@(obj) obj.strs, args, 'UniformOutput', false);
       out.strs = cat (dim, tmp{:});
@@ -1214,49 +1401,236 @@ classdef string
       out.isMissing = cat (dim, tmp{:});
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn {string} {@var{C} =} horzcat (@var{A}, @var{B}, @dots{})
+    ##
+    ## Horizontal concatenation of string arrays.
+    ##
+    ## @code{@var{C} = horzcat (@var{A}, @var{B}, @dots{}} is the equivalent of
+    ## the syntax @code{@var{B} = [@var{A}, @var{B}, @dots{}]} and horizontally
+    ## concatenates the string arrays @var{A}, @var{B}, @dots{}.  All input
+    ## arrays must have the same size except along the second dimension.  Any of
+    ## the input arrays may also be character matrixes, cell arrays of character
+    ## vectors, numeric arrays, or logical arrays of compatible size.
+    ##
+    ## @end deftypefn
     function out = horzcat (varargin)
       out = cat (2, varargin{:});
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn {string} {@var{C} =} vertcat (@var{A}, @var{B}, @dots{})
+    ##
+    ## Vertical concatenation of string arrays.
+    ##
+    ## @code{@var{C} = vertcat (@var{A}, @var{B}, @dots{}} is the equivalent of
+    ## the syntax @code{@var{B} = [@var{A}; @var{B}; @dots{}]} and vertically
+    ## concatenates the string arrays @var{A}, @var{B}, @dots{}.  All input
+    ## arrays must have the same size except along the second dimension.  Any of
+    ## the input arrays may also be character matrixes, cell arrays of character
+    ## vectors, numeric arrays, or logical arrays of compatible size.
+    ##
+    ## @end deftypefn
     function out = vertcat (varargin)
       out = cat (1, varargin{:});
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn  {string} {@var{B} =} repmat (@var{A}, @var{n})
+    ## @deftypefnx {string} {@var{B} =} repmat (@var{A}, @var{d1}, @dots{}, @var{dN})
+    ## @deftypefnx {string} {@var{B} =} repmat (@var{A}, @var{dimvec})
+    ##
+    ## Repeat copies of a string array.
+    ##
+    ## @code{@var{B} = repmat (@var{A}, @var{n})} returns a string array @var{B}
+    ## containing @var{n} copies of the input string array @var{A} along every
+    ## dimension of @var{A}.
+    ##
+    ## @code{@var{B} = repmat (@var{A}, @var{d1}, @dots{}, @var{dN})} returns an
+    ## array @var{B} containing copies of @var{A} along the dimensions specified
+    ## by the list of scalar integer values @var{d1}, @dots{}, @var{dN}, which
+    ## specify how many copies of @var{A} are made in each dimension.
+    ##
+    ## @code{@var{B} = repmat (@var{A}, @var{dimvec})} is equivalent to the
+    ## previous syntax with @code{@var{dimvec} = [@var{d1}, @dots{}, @var{dN}]}.
+    ##
+    ## @end deftypefn
     function this = repmat (this, varargin)
       this.strs = repmat (this.strs, varargin{:});
       this.isMissing = repmat (this.isMissing, varargin{:});
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn  {string} {@var{B} =} repelem (@var{A}, @var{n})
+    ## @deftypefnx {string} {@var{B} =} repelem (@var{A}, @var{d1}, @dots{}, @var{dN})
+    ##
+    ## Repeat copies of string array elements.
+    ##
+    ## @code{@var{B} = repelem (@var{A}, @var{n})} returns a string vector
+    ## @var{B} containing repeated elements of the input @var{A}, which must be
+    ## a string vector.  If @var{n} is a scalar, each element of @var{A} is
+    ## repeated @var{n} times along the non-singleton dimension of @var{A}.  If
+    ## @var{n} is a vector, it must have the same elemnts as @var{A}, in which
+    ## case it specifies the number of times to repeat each corresponding
+    ## element of @var{A}.
+    ##
+    ## @code{@var{B} =} repelem (@var{A}, @var{d1}, @dots{}, @var{dN}} returns
+    ## an array @var{B} with each element of @var{A} repeated according to the
+    ## the list of input arguments @code{@var{d1}, @dots{}, @var{dN}} each
+    ## corresponding to a different dimension @code{1:ndims (@var{A})} of the
+    ## input array @var{A}.  @var{d1}, @dots{}, @var{dN} must be either scalars
+    ## or vectors with the same length as the corresponding dimension of
+    ## @var{A} containing non-negative integer values specifying the number of
+    ## repetitions of each element along the corresponding dimension.
+    ##
+    ## @end deftypefn
+    function this = repelem (this, varargin)
+      this.strs = repelem (this.strs, varargin{:});
+      this.isMissing = repelem (this.isMissing, varargin{:});
+    endfunction
+
+    ## -*- texinfo -*-
+    ## @deftypefn {string} {@var{B} =} repelems (@var{A}, @var{R})
+    ##
+    ## Construct a vector of repeated elements from a string array.
+    ##
+    ## @code{@var{B} = repelems (@var{A}, @var{R})} returns a string vector
+    ## @var{B} containing repeated elements of the input @var{A}, which must be
+    ## a string vector.  @var{R} must be a @math{2xN} matrix of integers.
+    ## Entries in the first row of @var{R} correspond to the linear indexing of
+    ## the elements in @var{A} to be repeated.  The corresponding entries in the
+    ## second row of @var{R} specify the repeat count of each element.
+    ##
+    ## @end deftypefn
+    function this = repelems (this, R)
+      this.strs = repelems (this.strs, R);
+      this.isMissing = repelems (this.isMissing, R);
+    endfunction
+
+    ## -*- texinfo -*-
+    ## @deftypefn  {string} {@var{B} =} reshape (@var{A}, @var{d1}, @dots{}, @var{dN})
+    ## @deftypefnx {string} {@var{B} =} reshape (@var{A}, @dots{}, @qcode{[]}, @dots{})
+    ## @deftypefnx {string} {@var{B} =} reshape (@var{A}, @var{dimvec})
+    ##
+    ## Repeat copies of string array elements.
+    ##
+    ## @code{@var{B} = reshape (@var{A}, @var{d1}, @dots{}, @var{dN})} returns
+    ## a string array @var{B} with specified dimensions @var{d1}, @dots{},
+    ## @var{dN}, whose elements are taken columnwise from the string array
+    ## @var{A}.  The product of @var{d1}, @dots{}, @var{dN} must equal the total
+    ## number of elements in @var{A}.
+    ##
+    ## @code{@var{B} = reshape (@var{A}, @dots{}, @qcode{[]}, @dots{})} returns
+    ## a string array @var{B} with one dimension unspecified which is calculated
+    ## automatically so that the product of dimensions in @var{B} matches the
+    ## total elements in @var{A}, which must be divisible the product of
+    ## specified dimensions.  An empty matrix @qcode{([])} is used to flag the
+    ## unspecified dimension.
+    ##
+    ## @end deftypefn
     function this = reshape (this, varargin)
       this.strs = reshape (this.strs, varargin{:});
       this.isMissing = reshape (this.isMissing, varargin{:});
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn  {string} {@var{B} =} circshift (@var{A}, @var{n})
+    ## @deftypefnx {string} {@var{B} =} circshift (@var{A}, @var{n}, @var{dim})
+    ##
+    ## Circularly shift the elements in a string array.
+    ##
+    ## @code{@var{B} = circshift (@var{A}, @var{n})} circularly shifts the
+    ## elements of the string array @var{A} according to @var{n}.  If @var{n}
+    ## is a nonzero integer scalar, then the elements of @var{A} are shifted by
+    ## @var{n} elements along the first non-singleton dimension of @var{A}.  If
+    ## @var{n} is a vector, it must not be longer that the number of dimensions
+    ## of @var{A} with each value of @var{n} corresponding to a dimension in
+    ## @var{A}.   The sign of the value(s) in @var{n} specify the direction in
+    ## the elements of @var{A} are shifted.
+    ##
+    ## @code{@var{B} = circshift (@var{A}, @var{n}, @var{dim})} circularly
+    ## shifts the elements of the string array @var{A} along the dimension
+    ## specified by @var{dim}.  In this case, @var{n} must be a scalar integer
+    ## value.
+    ##
+    ## @end deftypefn
     function this = circshift (this, varargin)
       this.strs = circshift (this.strs, varargin{:});
       this.isMissing = circshift (this.isMissing, varargin{:});
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn {string} {@var{B} =} permute (@var{A}, @var{dims})
+    ##
+    ## Generalized transpose for a string N-D array.
+    ##
+    ## @code{@var{B} = permute (@var{A}, @var{dims})} returns the generalized
+    ## transpose of the string array @var{A} by rearranging its dimensions
+    ## according to the permutation vector specified in @var{dims}.
+    ##
+    ## @var{dims} must index all the dimensions @code{1:ndims (@var{A})} of the
+    ## input array @var{A}, in any order, but only once.  The @var{N}th
+    ## dimension of @var{A} gets remapped to the dimension in @var{B} specified
+    ## by @code{@var{dims}(@var{N})}.
+    ##
+    ## @end deftypefn
     function this = permute (this, varargin)
       this.strs = permute (this.strs, varargin{:});
       this.isMissing = permute (this.isMissing, varargin{:});
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn {string} {@var{A} =} ipermute (@var{B}, @var{dims})
+    ##
+    ## Inverse of the generalized transpose for a string N-D array.
+    ##
+    ## @code{@var{A} = ipermute (@var{B}, @var{dims})} returns the inverse of
+    ## the generalized transpose performed by the @code{permute} function.  The
+    ## expression @code{ipermute (permute (@var{A}, @var{dims}), @var{dims})}
+    ## returns the original array @var{A}.
+    ##
+    ## @var{dims} must index all the dimensions @code{1:ndims (@var{B})} of the
+    ## input array @var{B}, in any order, but only once.  The dimension of
+    ## @var{B} specified in @code{@var{dims}(@var{N})} gets remapped to the
+    ## @var{N}th dimension of @var{A}.
+    ##
+    ## @end deftypefn
     function this = ipermute (this, varargin)
       this.strs = ipermute (this.strs, varargin{:});
       this.isMissing = ipermute (this.isMissing, varargin{:});
     endfunction
 
-    function this = ctranspose (this, varargin)
-      this.strs = ctranspose (this.strs, varargin{:});
-      this.isMissing = ctranspose (this.isMissing, varargin{:});
-    endfunction
-
+    ## -*- texinfo -*-
+    ## @deftypefn {string} {@var{B} =} transpose (@var{A})
+    ##
+    ## Transpose a string matrix.
+    ##
+    ## @code{@var{B} = transpose (@var{A})} is the equivalent of the syntax
+    ## @code{@var{B} = @var{A}.'} and returns the transpose of the string
+    ## matrix @var{A}.
+    ##
+    ## @end deftypefn
     function this = transpose (this, varargin)
       this.strs = transpose (this.strs, varargin{:});
       this.isMissing = transpose (this.isMissing, varargin{:});
     endfunction
 
+    ## -*- texinfo -*-
+    ## @deftypefn {string} {@var{B} =} ctranspose (@var{A})
+    ##
+    ## Transpose a string matrix.
+    ##
+    ## @code{@var{B} = ctranspose (@var{A})} is the equivalent of the syntax
+    ## @code{@var{B} = @var{A}'} and returns the transpose of the string matrix
+    ## @var{A}.  For string arrays, @code{ctranspose} is identical to
+    ## @code{transpose}.
+    ##
+    ## @end deftypefn
+    function this = ctranspose (this, varargin)
+      this.strs = ctranspose (this.strs, varargin{:});
+      this.isMissing = ctranspose (this.isMissing, varargin{:});
+    endfunction
+
   endmethods
 
 ################################################################################
@@ -1324,7 +1698,11 @@ classdef string
 
       switch (s.type)
         case '()'
-          if (! isa (rhs, "string"))
+          if (isempty (rhs))
+            this.strs(s.subs{:}) = [];
+            this.isMissing(s.subs{:}) =[];
+            return;
+          elseif (! isa (rhs, "string"))
             rhs = string (rhs);
           endif
           this.strs(s.subs{:}) = rhs.strs;
@@ -1349,6 +1727,10 @@ classdef string
 
     endfunction
 
+  endmethods
+
+  methods (Access = private)
+
     ## Return a subset of the array
     function this = subset (this, varargin)
       this = this;
